@@ -3,7 +3,7 @@
 /**
  * Holds class PMA_Error
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -14,7 +14,7 @@ require_once './libraries/Message.class.php';
 /**
  * a single error
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 class PMA_Error extends PMA_Message
 {
@@ -67,42 +67,36 @@ class PMA_Error extends PMA_Message
      *
      * @var string
      */
-    protected $_file = '';
+    protected $file = '';
 
     /**
      * The line in which the error occured
      *
      * @var integer
      */
-    protected $_line = 0;
+    protected $line = 0;
 
     /**
      * Holds the backtrace for this error
      *
      * @var array
      */
-    protected $_backtrace = array();
+    protected $backtrace = array();
 
     /**
      * Unique id
      *
      * @var string
      */
-    protected $_hash = null;
+    protected $hash = null;
 
     /**
      * Constructor
      *
-     * @uses    debug_backtrace()
-     * @uses    PMA_Error::setNumber()
-     * @uses    PMA_Error::setMessage()
-     * @uses    PMA_Error::setFile()
-     * @uses    PMA_Error::setLine()
-     * @uses    PMA_Error::setBacktrace()
-     * @param   integer $errno
-     * @param   string  $errstr
-     * @param   string  $errfile
-     * @param   integer $errline
+     * @param integer $errno   error number
+     * @param string  $errstr  error message
+     * @param string  $errfile file
+     * @param integer $errline line
      */
     public function __construct($errno, $errstr, $errfile, $errline)
     {
@@ -112,9 +106,9 @@ class PMA_Error extends PMA_Message
         $this->setLine($errline);
 
         $backtrace = debug_backtrace();
-        // remove last two calls: debug_backtrace() and handleError()
-        unset($backtrace[0]);
-        unset($backtrace[1]);
+        // remove last three calls:
+        // debug_backtrace(), handleError() and addError()
+        $backtrace = array_slice($backtrace, 3);
 
         $this->setBacktrace($backtrace);
     }
@@ -122,105 +116,99 @@ class PMA_Error extends PMA_Message
     /**
      * sets PMA_Error::$_backtrace
      *
-     * @uses    PMA_Error::$_backtrace to set it
-     * @param   array $backtrace
+     * @param array $backtrace backtrace
+     *
+     * @return void
      */
     public function setBacktrace($backtrace)
     {
-        $this->_backtrace = $backtrace;
+        $this->backtrace = $backtrace;
     }
 
     /**
      * sets PMA_Error::$_line
      *
-     * @uses    PMA_Error::$_line to set it
-     * @param   integer $line
+     * @param integer $line the line
+     *
+     * @return void
      */
     public function setLine($line)
     {
-        $this->_line = $line;
+        $this->line = $line;
     }
 
     /**
      * sets PMA_Error::$_file
      *
-     * @uses    PMA_Error::$_file to set it
-     * @uses    PMA_Error::relPath()
-     * @param   string $file
+     * @param string $file the file
+     *
+     * @return void
      */
     public function setFile($file)
     {
-        $this->_file = PMA_Error::relPath($file);
+        $this->file = PMA_Error::relPath($file);
     }
 
 
     /**
-     * returns unique PMA_Error::$_hash, if not exists it will be created
+     * returns unique PMA_Error::$hash, if not exists it will be created
      *
-     * @uses    PMA_Error::$_hash as return value and to set it if required
-     * @uses    PMA_Error::getNumber()
-     * @uses    PMA_Error::getMessage()
-     * @uses    PMA_Error::getFile()
-     * @uses    PMA_Error::getLine()
-     * @uses    PMA_Error::getBacktrace()
-     * @uses    md5()
-     * @param   string $file
-     * @return  string PMA_Error::$_hash
+     * @return string PMA_Error::$hash
      */
     public function getHash()
     {
-        if (null === $this->_hash) {
-            $this->_hash = md5(
+        try {
+            $backtrace = serialize($this->getBacktrace());
+        } catch(Exception $e) {
+            $backtrace = '';
+        }
+        if ($this->hash === null) {
+            $this->hash = md5(
                 $this->getNumber() .
                 $this->getMessage() .
                 $this->getFile() .
                 $this->getLine() .
-                serialize($this->getBacktrace())
+                $backtrace
             );
         }
 
-        return $this->_hash;
+        return $this->hash;
     }
 
     /**
      * returns PMA_Error::$_backtrace
      *
-     * @uses    PMA_Error::$_backtrace as return value
-     * @return  array PMA_Error::$_backtrace
+     * @return array PMA_Error::$_backtrace
      */
     public function getBacktrace()
     {
-        return $this->_backtrace;
+        return $this->backtrace;
     }
 
     /**
-     * returns PMA_Error::$_file
+     * returns PMA_Error::$file
      *
-     * @uses    PMA_Error::$_file as return value
-     * @return  string PMA_Error::$_file
+     * @return string PMA_Error::$file
      */
     public function getFile()
     {
-        return $this->_file;
+        return $this->file;
     }
 
     /**
-     * returns PMA_Error::$_line
+     * returns PMA_Error::$line
      *
-     * @uses    PMA_Error::$_line as return value
-     * @return  integer PMA_Error::$_line
+     * @return integer PMA_Error::$line
      */
     public function getLine()
     {
-        return $this->_line;
+        return $this->line;
     }
 
     /**
      * returns type of error
      *
-     * @uses    PMA_Error::$errortype
-     * @uses    PMA_Error::getNumber()
-     * @return  string  type of error
+     * @return string  type of error
      */
     public function getType()
     {
@@ -230,9 +218,7 @@ class PMA_Error extends PMA_Message
     /**
      * returns level of error
      *
-     * @uses    PMA_Error::$$errorlevel
-     * @uses    PMA_Error::getNumber()
-     * @return  string  level of error
+     * @return string  level of error
      */
     public function getLevel()
     {
@@ -242,10 +228,7 @@ class PMA_Error extends PMA_Message
     /**
      * returns title prepared for HTML Title-Tag
      *
-     * @uses    PMA_Error::getTitle()
-     * @uses    htmlspecialchars()
-     * @uses    substr()
-     * @return  string   HTML escaped and truncated title
+     * @return string   HTML escaped and truncated title
      */
     public function getHtmlTitle()
     {
@@ -255,8 +238,6 @@ class PMA_Error extends PMA_Message
     /**
      * returns title for error
      *
-     * @uses    PMA_Error::getType()
-     * @uses    PMA_Error::getMessage()
      * @return string
      */
     public function getTitle()
@@ -265,102 +246,115 @@ class PMA_Error extends PMA_Message
     }
 
     /**
-     * Display HTML backtrace
+     * Get HTML backtrace
      *
-     * @uses    PMA_Error::getBacktrace()
-     * @uses    PMA_Error::relPath()
-     * @uses    PMA_Error::displayArg()
-     * @uses    count()
+     * @return void
      */
-    public function displayBacktrace()
+    public function getBacktraceDisplay()
     {
+        $retval = '';
+
         foreach ($this->getBacktrace() as $step) {
-            echo PMA_Error::relPath($step['file']) . '#' . $step['line'] . ': ';
-            if (isset($step['class'])) {
-                echo $step['class'] . $step['type'];
+            if (isset($step['file']) && isset($step['line'])) {
+                $retval .= PMA_Error::relPath($step['file']) . '#' . $step['line'] . ': ';
             }
-            echo $step['function'] . '(';
+            if (isset($step['class'])) {
+                $retval .= $step['class'] . $step['type'];
+            }
+            $retval .= $step['function'] . '(';
             if (isset($step['args']) && (count($step['args']) > 1)) {
-                echo "<br />\n";
+                $retval .= "<br />\n";
                 foreach ($step['args'] as $arg) {
-                    echo "\t";
-                    $this->displayArg($arg, $step['function']);
-                    echo ',' . "<br />\n";
+                    $retval .= "\t";
+                    $retval .= $this->getArg($arg, $step['function']);
+                    $retval .= ',' . "<br />\n";
                 }
             } elseif (isset($step['args']) && (count($step['args']) > 0)) {
                 foreach ($step['args'] as $arg) {
-                    $this->displayArg($arg, $step['function']);
+                    $retval .= $this->getArg($arg, $step['function']);
                 }
             }
-            echo ')' . "<br />\n";
+            $retval .= ')' . "<br />\n";
         }
+
+        return $retval;
     }
 
     /**
-     * Display a single function argument
-     * if $function is one of include/require the $arg is converted te relative path
+     * Get a single function argument
+     *
+     * if $function is one of include/require
+     * the $arg is converted to a relative path
      *
-     * @uses    PMA_Error::relPath()
-     * @uses    in_array()
-     * @uses    gettype()
      * @param string $arg
      * @param string $function
+     *
+     * @return string
      */
-    protected function displayArg($arg, $function)
+    protected function getArg($arg, $function)
     {
+        $retval = '';
         $include_functions = array(
             'include',
             'include_once',
             'require',
             'require_once',
         );
+        $connect_functions = array(
+            'mysql_connect',
+            'mysql_pconnect',
+            'mysqli_connect',
+            'mysqli_real_connect',
+            'PMA_DBI_connect',
+            'PMA_DBI_real_connect',
+        );
 
         if (in_array($function, $include_functions)) {
-            echo PMA_Error::relPath($arg);
+            $retval .= PMA_Error::relPath($arg);
+        } elseif (in_array($function, $connect_functions)
+            && getType($arg) === 'string'
+        ) {
+            $retval .= getType($arg) . ' ********';
         } elseif (is_scalar($arg)) {
-            echo gettype($arg) . ' ' . htmlspecialchars($arg);
+            $retval .= getType($arg) . ' ' . htmlspecialchars($arg);
         } else {
-            echo gettype($arg);
+            $retval .= getType($arg);
         }
+
+        return $retval;
     }
 
     /**
-     * Displays the error in HTML
+     * Gets the error as string of HTML
      *
-     * @uses    PMA_Error::getLevel()
-     * @uses    PMA_Error::getType()
-     * @uses    PMA_Error::getMessage()
-     * @uses    PMA_Error::displayBacktrace()
-     * @uses    PMA_Error::isDisplayed()
+     * @return string
      */
-    public function display()
+    public function getDisplay()
     {
-        echo '<div class="' . $this->getLevel() . '">';
-        if (! $this->isUserError()) {
-            echo '<strong>' . $this->getType() . '</strong>';
-            echo ' in ' . $this->getFile() . '#' . $this->getLine();
-            echo "<br />\n";
-        }
-        echo $this->getMessage();
-        if (! $this->isUserError()) {
-            echo "<br />\n";
-            echo "<br />\n";
-            echo "<strong>Backtrace</strong><br />\n";
-            echo "<br />\n";
-            echo $this->displayBacktrace();
-        }
-        echo '</div>';
         $this->isDisplayed(true);
+        $retval = '<div class="' . $this->getLevel() . '">';
+        if (! $this->isUserError()) {
+            $retval .= '<strong>' . $this->getType() . '</strong>';
+            $retval .= ' in ' . $this->getFile() . '#' . $this->getLine();
+            $retval .= "<br />\n";
+        }
+        $retval .= $this->getMessage();
+        if (! $this->isUserError()) {
+            $retval .= "<br />\n";
+            $retval .= "<br />\n";
+            $retval .= "<strong>Backtrace</strong><br />\n";
+            $retval .= "<br />\n";
+            $retval .= $this->getBacktraceDisplay();
+        }
+        $retval .= '</div>';
+
+        return $retval;
     }
 
     /**
      * whether this error is a user error
      *
-     * @uses    E_USER_WARNING
-     * @uses    E_USER_ERROR
-     * @uses    E_USER_NOTICE
-     * @uses    PMA_Error::getNumber()
-     * @return  boolean
+     * @return boolean
      */
     public function isUserError()
     {
@@ -373,19 +367,10 @@ class PMA_Error extends PMA_Message
      * prevent path disclusore in error message,
      * and make users feel save to submit error reports
      *
+     * @param string $dest path to be shorten
+     *
+     * @return string shortened path
      * @static
-     * @uses    PHP_OS()
-     * @uses    __FILE__()
-     * @uses    realpath()
-     * @uses    substr()
-     * @uses    explode()
-     * @uses    dirname()
-     * @uses    implode()
-     * @uses    count()
-     * @uses    array_pop()
-     * @uses    str_replace()
-     * @param   string $dest  path to be shorten
-     * @return  string shortened path
      */
     static function relPath($dest)
     {
@@ -397,7 +382,10 @@ class PMA_Error extends PMA_Message
             $path_separator = '/';
         }
 
-        $Ahere = explode($path_separator, realpath(dirname(__FILE__) . $path_separator . '..'));
+        $Ahere = explode(
+            $path_separator,
+            realpath(dirname(__FILE__) . $path_separator . '..')
+        );
         $Adest = explode($path_separator, $dest);
 
         $result = '.';
@@ -411,7 +399,11 @@ class PMA_Error extends PMA_Message
             }
         }
         $path = $result . str_replace(implode($path_separator, $Adest), '', $dest);
-        return str_replace($path_separator . $path_separator, $path_separator, $path);
+        return str_replace(
+            $path_separator . $path_separator,
+            $path_separator,
+            $path
+        );
     }
 }
 ?>
