@@ -1,10 +1,16 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * The MERGE storage engine
+ *
  * @package PhpMyAdmin-Engines
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
+ * The MERGE storage engine
  *
  * @package PhpMyAdmin-Engines
  */
