@@ -1,4 +1,5 @@
 <?php
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Used to create server variables documentation links
  * $VARIABLE_DOC_LINKS[string $name] = array(
@@ -10,8 +11,14 @@
  * string $chapter: chapter of "HTML, one page per chapter" documentation
  * string $type: type of system variable
  * string $format: if set to 'byte' it will format the variable
- * with PMA_formatByteDown()
+ * with PMA_Util::formatByteDown()
+ *
+ * @package PhpMyAdmin
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
+
 $VARIABLE_DOC_LINKS = array();
 $VARIABLE_DOC_LINKS['auto_increment_increment'] = array(
     'auto_increment_increment',
