@@ -2,17 +2,16 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
  * Gets some core libraries
  */
-require_once './libraries/common.inc.php';
+require_once 'libraries/common.inc.php';
 
 // Check parameters
-
-PMA_checkParameters(array('db', 'table'));
+PMA_Util::checkParameters(array('db', 'table'));
 
 /**
  * Defines the url to return to in case of error in a sql statement
@@ -47,23 +46,29 @@ if (PMA_isValid($_REQUEST['new_name'])) {
         }
         $result = false;
     } else {
-        $result = PMA_Table::moveCopy($db, $table, $_REQUEST['target_db'], $_REQUEST['new_name'],
-            $_REQUEST['what'], isset($_REQUEST['submit_move']), 'one_table');
+        $result = PMA_Table::moveCopy(
+            $db, $table, $_REQUEST['target_db'], $_REQUEST['new_name'],
+            $_REQUEST['what'], isset($_REQUEST['submit_move']), 'one_table'
+        );
 
         if (isset($_REQUEST['submit_move'])) {
             $message = PMA_Message::success(__('Table %s has been moved to %s.'));
         } else {
             $message = PMA_Message::success(__('Table %s has been copied to %s.'));
         }
-        $old = PMA_backquote($db) . '.' . PMA_backquote($table);
+        $old = PMA_Util::backquote($db) . '.'
+            . PMA_Util::backquote($table);
         $message->addParam($old);
-        $new = PMA_backquote($_REQUEST['target_db']) . '.' . PMA_backquote($_REQUEST['new_name']);
+        $new = PMA_Util::backquote($_REQUEST['target_db']) . '.'
+            . PMA_Util::backquote($_REQUEST['new_name']);
         $message->addParam($new);
 
         /* Check: Work on new table or on old table? */
-        if (isset($_REQUEST['submit_move']) || PMA_isValid($_REQUEST['switch_to_new'])) {
-            $db        = $_REQUEST['target_db'];
-            $table     = $_REQUEST['new_name'];
+        if (isset($_REQUEST['submit_move'])
+            || PMA_isValid($_REQUEST['switch_to_new'])
+        ) {
+            $db    = $_REQUEST['target_db'];
+            $table = $_REQUEST['new_name'];
         }
         $reload = 1;
     }
@@ -75,6 +80,21 @@ if (PMA_isValid($_REQUEST['new_name'])) {
     $result = false;
 }
 
+if ($GLOBALS['is_ajax_request'] == true) {
+    $response = PMA_Response::getInstance();
+    $response->addJSON('message', $message);
+    if ($message->isSuccess()) {
+        $response->addJSON('db', $GLOBALS['db']);
+        $response->addJSON(
+            'sql_query',
+            PMA_Util::getMessage(null, $sql_query)
+        );
+    } else {
+        $response->isSuccess(false);
+    }
+    exit;
+}
+
 /**
  * Back to the calling script
  */
